# mayarepacker  

<!-- [![PyPI Versions](https://img.shields.io/pypi/v/boip.svg)](https://pypi.org/project/boip) -->
<!-- [![Downloads](https://pepy.tech/badge/boip)](https://pepy.tech/project/boip) -->
<!-- [![license](https://img.shields.io/pypi/l/boip)](https://pypi.org/project/boip) -->
<!-- [![Supported Versions](https://img.shields.io/pypi/pyversions/boip.svg)](https://pypi.org/project/boip) -->
<!-- [![pytest](https://codecov.io/gh/InTack2/boip/branch/master/graph/badge.svg)](https://codecov.io/gh/InTack2/mayarepacker) -->
[![code style](https://img.shields.io/badge/code%20style-flake8-000000.svg)](https://pypi.org/-project/flake8/)  

Automatic package reloader for Maya.

## Features
This repository is a feature that makes it easy for TechnicalArtists to hot-load their tools when they create them in Maya.
